@@ -38,21 +38,17 @@ class DingDingPlugin(NotificationPlugin):
         return bool(self.get_option('access_token', project))
 
     def notify_users(self, group, event, *args, **kwargs):
+        if not self.is_configured(group.project):
+            return None
+
+        if self.should_notify(group, event):
+            self.send_msg(group, event, *args, **kwargs)
+        else:
+            return None
+
         self.post_process(group, event, *args, **kwargs)
 
-    def post_process(self, group, event, *args, **kwargs):
-        """
-        Process error.
-        """
-        if not self.is_configured(group.project):
-            return
-
-        if not self.should_notify(group, event):
-            return
-
-        if group.is_ignored():
-            return
-
+    def send_msg(self, group, event, *args, **kwargs):
         access_token = self.get_option('access_token', group.project)
         send_url = DingTalk_API.format(token=access_token)
         time = (event.datetime + timedelta(hours=8)).strftime("%Y-%m-%d %H:%M:%S")
